==> analytics_eda-0.1.0-py3-none-any.whl: analytics_eda/univariate/numeric/univariate_numeric_analysis.py <==
# Copyright 2025 ArchiStrata, LLC and Andrew Dabrowski
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from pathlib import Path

import pandas as pd

from ...core import write_json_report, missing_data_analysis, verify_numeric_column, distribution_analysis, outlier_analysis, inferential_analysis

def univariate_numeric_analysis(
    df: pd.DataFrame,
    column: str,
    report_root: str = 'reports/eda/univariate/numeric',
    iqr_multiplier: float = 1.5,
    z_thresh: float = 3.0,
    alpha: float = 0.05,
    popmean: float | None = None,
    popmedian: float | None = None,
    popvariance: float | None = None,
    bootstrap_samples: int = 1_000
) -> dict:
    """
    Conduct a full univariate analysis on a numeric series.

    Steps:
      1. Validate numeric column.
      2. Missing data analysis (counts, percentage, plot).
      3. Distribution analysis (descriptive stats, normality tests, visualizations).
      4. Outlier analysis (IQR, Z-score, robust Z-score with CSV exports).
      5. Inferential analysis (confidence intervals, goodness-of-fit, variance tests, effect size, bootstrap inference).
      6. Aggregation and saving of all results into a single JSON report.

    Args:
        df (pd.DataFrame): DataFrame containing the input data.
        column (str): Name of the numeric column to analyze.
        report_root (str): Base directory where report files will be saved.
        iqr_multiplier (float): IQR multiplier for outlier detection.
        z_thresh (float): Z-score threshold for outlier detection.
        alpha (float): Significance level for inferential tests and confidence intervals.
        popmean (float|None): Hypothesized population mean for inferential tests.
        popmedian (float|None): Hypothesized population median for inferential tests.
        popvariance (float|None): Hypothesized population variance (σ²) for inferential tests.
        bootstrap_samples (int): Number of bootstrap resamples for CI estimation.

    Returns:
        dict: A dictionary containing:
            'missing_data': Summary of missing data analysis,
            'distribution': Summary of distribution analysis,
            'outliers': Summary of outlier analysis,
            'inferential': Summary of inferential analysis.
    """
    # 1. Validate Numeric Column
    verify_numeric_column(df, column)
    s = df[column].copy()

    # Prepare directory
    save_dir = Path(report_root) / column.replace(' ', '_')
    save_dir.mkdir(parents=True, exist_ok=True)

    # 2. Missing Data Analysis
    missing_data = missing_data_analysis(s, save_dir)

    # 3. Distribution Analysis
    distribution_result = distribution_analysis(s, save_dir, alpha=alpha)
    series = distribution_result['series']

    # 4. Outlier Analysis
    outliers = outlier_analysis(series, save_dir, iqr_multiplier, z_thresh)

    # 5. Inferential Analysis
    inferential = inferential_analysis(
        series,
        alpha=alpha,
        popmean=popmean,
        popmedian=popmedian,
        popvariance=popvariance,
        bootstrap_samples=bootstrap_samples
    )

    # 6. Generate report
    report = {
        'missing_data': missing_data,
        'distribution': distribution_result['report'],
        'outliers': outliers,
        'inferential': inferential
    }

    report_path = save_dir / f"{column.replace(' ', '_')}_univariate_analysis_report.json"
    full_report = write_json_report(report, report_path)

    return full_report

def batch_univariate_numeric_analysis(
    df: pd.DataFrame,
    columns: list[str],
    report_root: str = 'reports/eda/univariate/numeric',
    **analysis_kwargs
) -> dict[str, dict]:
    """
    Runs univariate_numeric_analysis on each column in `columns`.

    Returns:
        dict mapping column name → analysis results dict.
    """
    summary = {}
    for col in columns:
        print(f"\n\n==== Univariate Numeric Analysis for '{col}' ====")
        summary[col] = univariate_numeric_analysis(df, col, report_root, **analysis_kwargs)
    return summary

==> analytics_eda-0.1.12-py3-none-any.whl: analytics_eda/univariate/numeric/univariate_numeric_analysis.py <==
# Copyright 2025 ArchiStrata, LLC and Andrew Dabrowski
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from pathlib import Path

import pandas as pd

from ...core import write_json_report, missing_data_analysis, validate_numeric_named_series, numeric_distribution_analysis, outlier_analysis, numeric_inferential_analysis

def univariate_numeric_analysis(
    series: pd.Series,
    report_root: str = 'reports/eda/univariate/numeric',
    iqr_multiplier: float = 1.5,
    z_thresh: float = 3.0,
    alpha: float = 0.05,
    popmean: float | None = None,
    popmedian: float | None = None,
    popvariance: float | None = None,
    bootstrap_samples: int = 1_000
) -> dict:
    """
    Conduct a full univariate analysis on a numeric series.

    Steps:
      1. Validate numeric series.
      2. Missing data analysis (counts, percentage, plot).
      3. Distribution analysis (descriptive stats, normality tests, visualizations).
      4. Outlier analysis (IQR, Z-score, robust Z-score with CSV exports).
      5. Inferential analysis (confidence intervals, goodness-of-fit, variance tests, effect size, bootstrap inference).
      6. Aggregation and saving of all results into a single JSON report.

    Args:
        series (pd.Series): Series to analyze.
        report_root (str): Base directory where report files will be saved.
        iqr_multiplier (float): IQR multiplier for outlier detection.
        z_thresh (float): Z-score threshold for outlier detection.
        alpha (float): Significance level for inferential tests and confidence intervals.
        popmean (float|None): Hypothesized population mean for inferential tests.
        popmedian (float|None): Hypothesized population median for inferential tests.
        popvariance (float|None): Hypothesized population variance (σ²) for inferential tests.
        bootstrap_samples (int): Number of bootstrap resamples for CI estimation.

    Returns:
        dict: A dictionary containing:
            'missing_data': Summary of missing data analysis,
            'distribution': Summary of distribution analysis,
            'outliers': Summary of outlier analysis,
            'inferential': Summary of inferential analysis.
    """
    # 1. Validate Numeric
    validate_numeric_named_series(series)

    # Always work from a copy
    s = series.copy()

    # Prepare directory
    save_dir = Path(report_root) / series.name.replace(' ', '_')
    save_dir.mkdir(parents=True, exist_ok=True)

    # 2. Missing Data Analysis
    missing_data = missing_data_analysis(s, save_dir)

    # 3. Distribution Analysis
    distribution_result = numeric_distribution_analysis(s, save_dir, alpha=alpha)
    series = distribution_result['series']

    # 4. Outlier Analysis
    outliers = outlier_analysis(series, save_dir, iqr_multiplier, z_thresh)

    # 5. Inferential Analysis
    inferential = numeric_inferential_analysis(
        series,
        alpha=alpha,
        popmean=popmean,
        popmedian=popmedian,
        popvariance=popvariance,
        bootstrap_samples=bootstrap_samples
    )

    # 6. Generate report
    report = {
        'missing_data': missing_data,
        'distribution': distribution_result['report'],
        'outliers': outliers,
        'inferential': inferential
    }

    report_path = save_dir / f"{series.name.replace(' ', '_')}_univariate_analysis_report.json"
    full_report = write_json_report(report, report_path)

    return full_report
